@@ -9,9 +9,10 @@ import yaml
 from botocore.client import BaseClient
 
 from dstack import version
-from dstack.aws import jobs, secrets, logs, local
+from dstack.aws import jobs, logs, local
 from dstack.backend import InstanceType, RequestStatus, RequestHead
 from dstack.jobs import Job, JobStatus, Requirements
+from dstack.repo import RepoAddress
 from dstack.runners import Resources, Runner, Gpu
 
 CREATE_INSTANCE_RETRY_RATE_SECS = 3
@@ -33,7 +34,6 @@ def _serialize_runner(runner: Runner) -> dict:
         "request_id": runner.request_id,
         "resources": resources,
         "job": jobs.serialize_job(runner.job),
-        "secret_names": runner.secret_names
     }
     return data
 
@@ -50,7 +50,6 @@ def _unserialize_runner(data: dict) -> Runner:
             data["resources"].get("local") is True,
         ),
         jobs.unserialize_job(data["job"]),
-        data.get("secret_names") or [],
     )
 
 
@@ -411,14 +410,21 @@ def instance_profile_arn(iam_client: BaseClient, bucket_name: str) -> str:
             raise e
 
 
-def _get_ami_image(ec2_client: BaseClient, cuda: bool) -> Tuple[str, str]:
+def _get_default_ami_image_version() -> Optional[str]:
+    if version.__is_release__:
+        return version.__version__
+    else:
+        return None
+
+
+def _get_ami_image(ec2_client: BaseClient, cuda: bool, _version: Optional[str] = _get_default_ami_image_version()) \
+        -> Tuple[str, str]:
     ami_name = "dstack"
     if cuda:
         ami_name = ami_name + "-cuda-11.1"
-    if version.__is_release__:
-        ami_name = ami_name + f"-{version.__version__}"
-    else:
-        ami_name = "[stgn] " + ami_name + "-*"
+    if not version.__is_release__:
+        ami_name = "[stgn] " + ami_name
+    ami_name = ami_name + f"-{_version or '*'}"
     response = ec2_client.describe_images(Filters=[
         {
             'Name': 'name',
@@ -430,7 +436,10 @@ def _get_ami_image(ec2_client: BaseClient, cuda: bool) -> Tuple[str, str]:
         ami = next(iter(sorted(images, key=lambda i: i["CreationDate"], reverse=True)))
         return ami["ImageId"], ami["Name"]
     else:
-        raise Exception(f"Can't find an AMI image '{ami_name}")
+        if _version:
+            return _get_ami_image(ec2_client, cuda, _version=None)
+        else:
+            raise Exception(f"Can't find an AMI image prefix='{ami_name}")
 
 
 def _run_instance(ec2_client: BaseClient, iam_client: BaseClient, bucket_name: str, region_name: str,
@@ -528,18 +537,17 @@ def _run_instance_retry(ec2_client: BaseClient, iam_client: BaseClient, bucket_n
             raise e
 
 
-def run_job(secretsmanager_client: BaseClient, logs_client: BaseClient, ec2_client: BaseClient, iam_client: BaseClient,
+def run_job(logs_client: BaseClient, ec2_client: BaseClient, iam_client: BaseClient,
             s3_client: BaseClient, bucket_name: str, region_name, subnet_id: Optional[str], job: Job):
     if job.status == JobStatus.SUBMITTED:
         runner = None
         try:
             job.runner_id = uuid.uuid4().hex
             jobs.update_job(s3_client, bucket_name, job)
-            secret_names = secrets.list_secret_names(secretsmanager_client, bucket_name)
             if job.requirements and job.requirements.local:
                 resources = local.check_runner_resources(job.runner_id)
                 if _matches(resources, job.requirements):
-                    runner = Runner(job.runner_id, None, resources, job, secret_names)
+                    runner = Runner(job.runner_id, None, resources, job)
                     _create_runner(logs_client, s3_client, bucket_name, runner)
                     runner.request_id = local.start_runner_process(job.runner_id)
                 else:
@@ -548,7 +556,7 @@ def run_job(secretsmanager_client: BaseClient, logs_client: BaseClient, ec2_clie
                     sys.exit(f"Local resources do not match requirements")
             else:
                 instance_type = _get_instance_type(ec2_client, job.requirements)
-                runner = Runner(job.runner_id, None, instance_type.resources, job, secret_names)
+                runner = Runner(job.runner_id, None, instance_type.resources, job)
                 _create_runner(logs_client, s3_client, bucket_name, runner)
                 if instance_type:
                     runner.request_id = _run_instance_retry(ec2_client, iam_client, bucket_name, region_name, subnet_id,
@@ -695,10 +703,10 @@ def _stop_runner(ec2_client: BaseClient, s3_client: BaseClient, bucket_name: str
     _delete_runner(s3_client, bucket_name, runner)
 
 
-def stop_job(ec2_client: BaseClient, s3_client: BaseClient, bucket_name: str, repo_user_name: str, repo_name: str,
+def stop_job(ec2_client: BaseClient, s3_client: BaseClient, bucket_name: str, repo_address: RepoAddress,
              job_id: str, abort: bool):
-    job_head = jobs.list_job_head(s3_client, bucket_name, repo_user_name, repo_name, job_id)
-    job = jobs.get_job(s3_client, bucket_name, repo_user_name, repo_name, job_id)
+    job_head = jobs.list_job_head(s3_client, bucket_name, repo_address, job_id)
+    job = jobs.get_job(s3_client, bucket_name, repo_address, job_id)
     runner = _get_runner(s3_client, bucket_name, job.runner_id) if job else None
     request_status = get_request_head(ec2_client, s3_client, bucket_name, job,
                                       runner).status if job else RequestStatus.TERMINATED
