@@ -1,11 +1,13 @@
 import os
+import webbrowser
 
 import pkg_resources
 from fastapi import FastAPI
 from starlette.responses import HTMLResponse, JSONResponse
 from starlette.staticfiles import StaticFiles
 
-from dstack.dashboard import repos, runs, artifacts, secrets, tags
+from dstack.dashboard import repos, runs, artifacts, secrets, tags, logs
+from dstack.repo import load_repo_data, _repo_address_path
 
 app = FastAPI(docs_url="/api/docs")
 app.include_router(repos.router)
@@ -13,11 +15,20 @@ app.include_router(runs.router)
 app.include_router(artifacts.router)
 app.include_router(secrets.router)
 app.include_router(tags.router)
+app.include_router(logs.router)
 
 
 @app.on_event("startup")
 async def startup_event():
-    print(f"The dashboard API is available at http://{os.getenv('DSTACK_HOST')}:{os.getenv('DSTACK_PORT')}/api/docs")
+    url = f"http://{os.getenv('DSTACK_DASHBOARD_HOST')}:{os.getenv('DSTACK_DASHBOARD_PORT')}"
+    try:
+        repo_data = load_repo_data()
+        url += f"/{_repo_address_path(repo_data)}"
+    except Exception:
+        pass
+    print(f"The dashboard is available at {url}")
+    if os.getenv('DSTACK_DASHBOARD_HEADLESS').strip().lower() != "true":
+        webbrowser.open(url)
 
 
 app.mount("/", StaticFiles(packages=["dstack.dashboard"], html=True), name="static")
